SystemOrganization addCategory: #'Seaside-Tests-UTF8'!

!GRPackage class methodsFor: '*seaside-tests-utf8' stamp: 'lr 2/17/2010 15:14'!
seasideTestsUtf8
	^ self new
		name: 'Seaside-Tests-UTF8';
		description: 'Unit tests for UTF8 support.';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

WAContextTest subclass: #WAUtf8CookieTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8CookieTest methodsFor: 'configuration' stamp: 'pmm 9/8/2013 15:37'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8CookieTest methodsFor: 'tests' stamp: 'pmm 9/8/2013 15:28'!
testWriteOn
	| expiry cookie |
	expiry := DateAndTime year: 2007 month: 11 day: 21 hour: 14 minute: 42 second: 48 offset: (Duration days: 0 hours: 2 minutes: 0 seconds: 0).
	cookie := WACookie key: 'ikuser' value: '1234'.
	self assert: cookie oldNetscapeString = 'ikuser=1234'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Version=1'.
	
	cookie expiry: expiry.
	cookie maxAge: 3600.
	self assert: cookie oldNetscapeString = 'ikuser=1234; expires=Wed, 21-Nov-2007 12:42:48 GMT'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Max-Age="3600"; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Max-Age="3600"; Version=1'.
	
	" #('C3' 'A4' 'C3' 'BC')"
	cookie path: '/seaside/', (String with: (Character codePoint: 228) with: (Character codePoint: 252)).
	self assert: cookie oldNetscapeString = 'ikuser=1234; expires=Wed, 21-Nov-2007 12:42:48 GMT; path=/seaside/%C3%A4%C3%BC'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Version=1'.
	
	cookie value: nil.
	self assert: cookie oldNetscapeString = 'ikuser=; expires=Wed, 21-Nov-2007 12:42:48 GMT; path=/seaside/%C3%A4%C3%BC'.
	self assert: cookie rfc2109String = 'ikuser=""; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Version=1'.
	self assert: cookie rfc2965String = 'ikuser=""; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Version=1'.
	
	cookie value: '1234'.
	cookie domain: 'www.example.com'.
	cookie ports: (Array with: 80 with: 433).
	self assert: cookie oldNetscapeString = 'ikuser=1234; expires=Wed, 21-Nov-2007 12:42:48 GMT; path=/seaside/%C3%A4%C3%BC; domain=www.example.com'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; domain="www.example.com"; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Port="80,433"; domain="www.example.com"; Version=1'.
	
	cookie discard: true.
	cookie secure: true.
	cookie httpOnly: true.
	self assert: cookie oldNetscapeString = 'ikuser=1234; expires=Wed, 21-Nov-2007 12:42:48 GMT; path=/seaside/%C3%A4%C3%BC; domain=www.example.com; Secure; HttpOnly'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; domain="www.example.com"; Secure; HttpOnly; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Port="80,433"; domain="www.example.com"; Secure; HttpOnly; Discard; Version=1'.
	
	cookie comment: 'FIS Heer username'.
	cookie commentUrl: 'http://www.example.com/session-cookie.html'.
	self assert: cookie oldNetscapeString = 'ikuser=1234; expires=Wed, 21-Nov-2007 12:42:48 GMT; path=/seaside/%C3%A4%C3%BC; domain=www.example.com; Secure; HttpOnly'.
	self assert: cookie rfc2109String = 'ikuser="1234"; Comment="FIS Heer username"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; domain="www.example.com"; Secure; HttpOnly; Version=1'.
	self assert: cookie rfc2965String = 'ikuser="1234"; Comment="FIS Heer username"; CommentURL="http://www.example.com/session-cookie.html"; Max-Age="3600"; path="/seaside/%C3%A4%C3%BC"; Port="80,433"; domain="www.example.com"; Secure; HttpOnly; Discard; Version=1'! !

WAContextTest subclass: #WAUtf8ResponseGeneratorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8ResponseGeneratorTest methodsFor: 'private' stamp: 'pmm 3/16/2013 16:58'!
assertContents: aString
	self assert: self requestContext response contents = aString! !

!WAUtf8ResponseGeneratorTest methodsFor: 'configuration' stamp: 'pmm 3/16/2013 17:03'!
createRequest
 	| request |
	request := super createRequest.
	request url
		addToPath: 'book';
		addToPath: (String with: (Character codePoint: 225) with: (Character codePoint: 269)).
	^ request! !

!WAUtf8ResponseGeneratorTest methodsFor: 'tests' stamp: 'pmm 3/16/2013 17:01'!
testForbidden
	| generator |
	generator := WAResponseGenerator on: self requestContext.
	self requestContext response nextPutAll: 'oops'.
	generator forbidden.
	self assertContents: 'Error: you are forbidden to access "/book/', (String with: (Character codePoint: 225) with: (Character codePoint: 269)), '"'! !

!WAUtf8ResponseGeneratorTest methodsFor: 'tests' stamp: 'pmm 3/16/2013 17:02'!
testNotFound
	| generator |
	generator := WAResponseGenerator on: self requestContext.
	self requestContext response nextPutAll: 'oops'.
	generator notFound.
	self assertContents: '/book/', (String with: (Character codePoint: 225) with: (Character codePoint: 269)), ' not found'! !

WAContextTest subclass: #WAUtf8ResponseTest
	instanceVariableNames: 'response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
assertLines: anArray
	self assert: self lines = anArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
contents
	| stream |
	stream := WriteStream on: String new.
	self response writeOn: stream.
	^ stream contents! !

!WAUtf8ResponseTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'jf 9/30/2009 01:06'!
lines
	"Answer the response as an array of lines, to be used within the tests."
	| result stream |
	result := OrderedCollection new.
	stream := self contents readStream.
	[ stream atEnd ] whileFalse: 
		[ result add: (stream greaseUpToAll: (String 
					with: Character cr
					with: Character lf)) ].
	^ result asArray! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:57'!
response
	^ response ifNil: [ response := WABufferedResponse new ]! !

!WAUtf8ResponseTest methodsFor: 'tests' stamp: 'pmm 7/5/2009 20:04'!
testRedirectTo
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self response redirectTo: url.
	self assertLines:  #('HTTP/1.1 302 Found'
		'Location: http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'
		'Content-Length: 0' '')! !

!WAUtf8ResponseTest methodsFor: 'private' stamp: 'pmm 7/5/2009 19:53'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

WAContextTest subclass: #WAUtf8UrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8UrlTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8UrlTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAUtf8UrlTest methodsFor: 'tests' stamp: 'pmm 3/16/2013 16:54'!
testPathStringUnencoded
	| url |
	url := (WAUrl absolute: 'http://book.seaside.st/book/%C3%A1%C4%8D')
		decodedWith: (GRCodec forEncoding: 'utf-8').
	self assert: url pathStringUnencoded =  ('/book/', (String with: (Character codePoint: 225) with: (Character codePoint: 269)))! !

!WAUtf8UrlTest methodsFor: 'tests' stamp: 'pmm 7/5/2009 20:06'!
testPrintString
	| url |
	url :=  WAUrl absolute: 'http://www.seaside.st/'.
	url addToPath: self unicodeString.
	self assert: url printString = 'http://www.seaside.st/%C2%A5%C2%A3%E2%82%AC%24%C2%A2%E2%82%A1%E2%82%A2%E2%82%A3%E2%82%A4%E2%82%A5%E2%82%A6%E2%82%A7%E2%82%A8%E2%82%A9%E2%82%AA%E2%82%AB%E2%82%AD%E2%82%AE%E2%82%AF'! !

!WAUtf8UrlTest methodsFor: 'private' stamp: 'pmm 7/5/2009 20:05'!
unicodeString
	^ self asString: #(165 163 8364 36 162 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8365 8366 8367)! !

!WABufferedResponseTest methodsFor: '*seaside-tests-utf8' stamp: 'pmm 8/25/2011 14:26'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WABufferedResponseTest methodsFor: '*seaside-tests-utf8' stamp: 'pmm 8/25/2011 14:27'!
decodedUnicodeString
	^ self asString: #(252 116 102 45 56)! !

!WABufferedResponseTest methodsFor: '*seaside-tests-utf8' stamp: 'pmm 8/25/2011 14:28'!
encodedUnicodeString
	^ self asString: #(195 188 116 102 45 56)! !

!WABufferedResponseTest methodsFor: '*seaside-tests-utf8' stamp: 'pmm 8/26/2011 09:52'!
testResetKeepsStreamKind
	| resetPossible |
	response := WABufferedResponse
		on: ((GRCodec forEncoding: 'utf-8')
			encoderFor: (GRPlatform current writeCharacterStreamOn: String new)).
	resetPossible := self response
		status: WAResponse statusNotFound;
		attachmentWithFileName: 'upload.csv';
		nextPutAll: 'the wrong content';
		resetIfPossible.
	self assert: resetPossible.
	self response
		status: WAResponse statusImATeapot;
		headerAt: 'X-The-Header' put: 'the value';
		nextPutAll: self decodedUnicodeString.
	self assertLines: (Array
		with: 'HTTP/1.1 418 I''m a teapot'
		with: 'X-The-Header: the value'
		with: 'Content-Length: 6'
		with: ''
		with: self encodedUnicodeString)! !

!WABufferedResponseTest methodsFor: '*seaside-tests-utf8' stamp: 'pmm 8/25/2011 14:26'!
unicodeString
	^ self asString: 'tf-8'! !

TestCase subclass: #WAUtf8FileTest
	instanceVariableNames: 'file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-UTF8'!

!WAUtf8FileTest methodsFor: 'private' stamp: 'lr 7/25/2011 20:14'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAUtf8FileTest methodsFor: 'private' stamp: 'pmm 11/15/2009 10:47'!
brokenUnicodeString
	^ self asString: #(83 195 169 195 164 115 195 174 100 195 169)! !

!WAUtf8FileTest methodsFor: 'running' stamp: 'pmm 11/14/2009 22:13'!
setUp
	file := WAFile new! !

!WAUtf8FileTest methodsFor: 'tests' stamp: 'pmm 8/2/2011 20:53'!
testContents
	file contents: #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self assert: file rawContents = #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self assert: (file contentsDecodedUsing: 'ISO-8859-1') = self brokenUnicodeString.
	self assert: (file contentsDecodedUsing: 'UTF-8') = self unicodeString! !

!WAUtf8FileTest methodsFor: 'tests' stamp: 'pmm 11/15/2009 10:44'!
testContentsDecoded
	file contents:  #(83 195 169 195 164 115 195 174 100 195 169) asByteArray.
	self should: [ file contentsDecoded ] raise: WAIllegalStateException.
	file contentType: 'text/plain'.
	self should: [ file contentsDecoded ] raise: WAIllegalStateException.
	file contentType: 'text/plain; charset=utf-8' seasideMimeType.
	self assert: file contentsDecoded = self unicodeString
	! !

!WAUtf8FileTest methodsFor: 'private' stamp: 'pmm 11/15/2009 10:43'!
unicodeString
	^ self asString: #(83 233 228 115 238 100 233)! !
